Layout

Trait Layout 

pub trait Layout {
    type TypeLayout: Copy + Default + Debug + Eq + PartialEq;
    type FieldLayout: Copy + Default + Debug + Eq + PartialEq;
    type OpaqueLayout: Copy + Default + Debug + Eq + PartialEq;
}
A collection of types encoding the layout of a type.

Required Associated Types

type TypeLayout: Copy + Default + Debug + Eq + PartialEq

The type used to encode the layout of the type itself.

type FieldLayout: Copy + Default + Debug + Eq + PartialEq

The type used to encode the layout of a field in a record.

type OpaqueLayout: Copy + Default + Debug + Eq + PartialEq

The type used to encode the layout of an opaque type.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Layout for ()

Implementors